OidcAuthorizeResponse class

Successful Authentication Response

Annotations
  • @JsonSerializable.new(createFactory: true, createToJson: false, converters: OidcInternalUtilities.commonConverters)

Constructors

OidcAuthorizeResponse({required Map<String, dynamic> src, String? codeVerifier, Uri? redirectUri, String? code, String? sessionState, String? state, Uri? iss, String? nonce, List<String> scope = const [], @Deprecated(_implicitWarning) String? tokenType, @Deprecated(_implicitWarning) Duration? expiresIn, @Deprecated(_implicitWarning) String? accessToken, @Deprecated(_implicitWarning) String? idToken})
OidcAuthorizeResponse.fromJson(Map<String, dynamic> src)
factory

Properties

accessToken String?
getter/setter pair
code String?
REQUIRED, if the request_type was code.
getter/setter pair
codeVerifier String?
getter/setter pair
expiresIn Duration?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idToken String?
getter/setter pair
iss Uri?
OPTIONAL.
getter/setter pair
nonce String?
getter/setter pair
redirectUri Uri?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope List<String>
getter/setter pair
sessionState String?
getter/setter pair
src Map<String, dynamic>
The source json object.
finalinherited
state String?
getter/setter pair
tokenType String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String key) → dynamic
gets a value from the src json
inherited