clientId property

  1. @JsonKey.new(name: OidcConstants_AuthParameters.clientId)
String? clientId
final

OPTIONAL.

OAuth 2.0 Client Identifier valid at the Authorization Server.

When both client_id and id_token_hint are present, the OP MUST verify that the Client Identifier matches the one used when issuing the ID Token.

The most common use case for this parameter is to specify the Client Identifier when post_logout_redirect_uri is used but id_token_hint is not.

Another use is for symmetrically encrypted ID Tokens used as id_token_hint values that require the Client Identifier to be specified by other means, so that the ID Tokens can be decrypted by the OP.

Implementation

@JsonKey(name: OidcConstants_AuthParameters.clientId)
final String? clientId;