idTokenHint property
RECOMMENDED.
ID Token previously issued by the OP to the RP passed to the Logout Endpoint as a hint about the End-User's current authenticated session with the Client.
This is used as an indication of the identity of the End-User that the RP is requesting be logged out by the OP.
Implementation
@JsonKey(name: OidcConstants_AuthParameters.idTokenHint)
final String? idTokenHint;